﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Scheduling;
using MindFusion.Scheduling.Wpf;

namespace WpfPlannerCustomItems
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			calendar.ResourceViewSettings.LaneSize = 54;

			FontFamily font = new FontFamily("Segoe UI");
			calendar.ItemSettings.CalendarStyle.FontFamily = font;
			calendar.ItemSettings.CalendarStyle.Background = Brushes.White;
			calendar.ItemSettings.CalendarStyle.BorderBrush = Brushes.SlateGray;
			calendar.ItemSettings.SelectedItemStyle.FontFamily = font;
			calendar.ItemSettings.SelectedItemStyle.Background = Brushes.White;
			calendar.ItemSettings.SelectedItemStyle.BorderBrush = Brushes.SlateGray;
			calendar.ItemSettings.PointedItemStyle.FontFamily = font;
			calendar.ItemSettings.PointedItemStyle.Background = Brushes.White;
			calendar.ItemSettings.PointedItemStyle.BorderBrush = Brushes.SlateGray;
			calendar.ItemSettings.PointedSelectedItemStyle.FontFamily = font;
			calendar.ItemSettings.PointedSelectedItemStyle.Background = Brushes.White;
			calendar.ItemSettings.PointedSelectedItemStyle.BorderBrush = Brushes.SlateGray;
		}

		private void taskList_PreviewMouseDown(object sender, MouseButtonEventArgs e)
		{
			mouseDown = e.LeftButton == MouseButtonState.Pressed;
		}

		private void taskList_MouseMove(object sender, MouseEventArgs e)
		{
			if (taskList.SelectedItem != null && mouseDown)
			{
				mouseDown = false;
				string data = ((ListBoxItem)taskList.SelectedItem).Content.ToString();
				DragDrop.DoDragDrop(taskList, data, DragDropEffects.Copy);
			}
		}

		private void calendar_DragOver(object sender, DragEventArgs e)
		{
			e.Effects = DragDropEffects.None;
			if (e.Data.GetDataPresent(typeof(string)))
			{
				DateTime? date = calendar.GetDateAt(e.GetPosition(calendar));
				if (date != null)
					e.Effects = DragDropEffects.Copy;
			}
		}

		private void calendar_Drop(object sender, DragEventArgs e)
		{
			if (e.Data.GetDataPresent(typeof(string)))
			{
				Point point = e.GetPosition(calendar);
				DateTime? date = calendar.GetDateAt(point);
				Resource resource = calendar.GetResourceAt(point);
				if (date != null && resource != null)
				{
					string task = (string)e.Data.GetData(typeof(string));
					Appointment appointment = new Appointment();
					appointment.HeaderText = task;
					appointment.DescriptionText = "Description for " + task;
					appointment.StartTime = date.Value;
					appointment.EndTime = appointment.StartTime.AddDays(2);
					appointment.Resources.Add(resource);
					calendar.Schedule.Items.Add(appointment);
				}
			}
		}


		private bool mouseDown = false;
	}
}
